import { DataContext } from "@/Contexts/DataContextProvider";
import React, { useState, useEffect, useCallback } from "react";

function CourseForm({ initialBenefits = [], onBenefitChange, errors }) {
    const [benefits, setBenefits] = useState(initialBenefits);

    const stableOnBenefitChange = useCallback(onBenefitChange, []);

    useEffect(() => {
        onBenefitChange(benefits);
    }, [benefits]);

    const handleAddBenefit = () => {
        setBenefits([...benefits, { emoji: "😊", value: "" }]);
    };

    const handleRemoveBenefit = (index) => {
        const updatedBenefits = [...benefits];
        updatedBenefits.splice(index, 1);
        setBenefits(updatedBenefits);
    };

    const handleEmojiChange = (index, emoji) => {
        const updatedBenefits = [...benefits];
        updatedBenefits[index].emoji = emoji;
        setBenefits(updatedBenefits);
    };

    const handleInputChange = (index, value) => {
        const updatedBenefits = [...benefits];
        updatedBenefits[index].value = value;
        setBenefits(updatedBenefits);
    };

    return (
        <>
            <div className="form-group mt-2">
                <label className="give" htmlFor="emoji">
                    What will course takers learn from your course?
                </label>
                {benefits.map((benefit, index) => (
                    <div className="emoji-benefits-container" key={index}>
                        <select
                            value={benefit.emoji}
                            name="emoji"
                            onChange={(e) =>
                                handleEmojiChange(index, e.target.value)
                            }
                        >
                            <option value="😊">😊</option>
                            <option value="❤️">❤️</option>
                            <option value="👍">👍</option>
                            {/* Add more commonly used emojis as needed */}
                        </select>
                        {errors?.emoji && (
                            <div className="text-danger">{errors?.emoji}</div>
                        )}

                        <input
                            className="inputElement input-field"
                            name="benefits"
                            placeholder="Tell any benefits"
                            value={benefit.value}
                            onChange={(e) =>
                                handleInputChange(index, e.target.value)
                            }
                        />
                        {errors?.benefits && (
                            <div className="text-danger">
                                {errors?.benefits}
                            </div>
                        )}

                        <button
                            type="button"
                            className="faqremove-btn ml-3"
                            onClick={() => handleRemoveBenefit(index)}
                        >
                            <img
                                style={{ height: "30px" }}
                                src="/images/delbtn.png"
                                alt="Delete Button"
                            />
                        </button>
                    </div>
                ))}
            </div>
            <div className="flex justify-end">
                <button
                    className="add-benefit border p-2 rounded-3"
                    type="button"
                    onClick={handleAddBenefit}
                >
                    + Add benefit
                </button>
            </div>
        </>
    );
}

export default CourseForm;
